﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.PackingEncoding.MultiComponentVector {
  [Item("ChangePositionMoveAttribute", "Specifies the tabu attributes for a change position move on an multi component vector.")]
  [StorableClass]
  public class ChangePositionMoveAttribute : MultiComponentVectorMoveAttribute {
    [Storable]
    public int AffectedGroup { get; protected set; }
    [Storable]
    public int Index { get; protected set; }      
    [Storable]
    public int ItemID { get; protected set; }
    [Storable]
    public int TargetIndex { get; protected set; }

    [StorableConstructor]
    protected ChangePositionMoveAttribute(bool deserializing) : base(deserializing) { }
    protected ChangePositionMoveAttribute(ChangePositionMoveAttribute original, Cloner cloner)
      : base(original, cloner) {
        this.Index = original.Index;
        this.TargetIndex = original.TargetIndex;      
      this.ItemID = original.ItemID;
    }
    public ChangePositionMoveAttribute() : this(-1, -1, -1, -1, -1) { }
    public ChangePositionMoveAttribute(int affectedGroup, int index, int itemID, int targetIndex, double moveQuality)
      : base(moveQuality) {
        AffectedGroup = affectedGroup;
        Index = index;
        TargetIndex = targetIndex;
        ItemID = itemID;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ChangePositionMoveAttribute(this, cloner);
    }
  }
}
